pub struct LoweredAggregate {
pub aggregate: Arc<AggregateFunctionExpr>,
pub filter: Option<Arc<dyn PhysicalExpr>>,
pub order_bys: Vec<PhysicalSortExpr>,
}Expand description
Result of lowering a logical aggregate expression into physical aggregate planning pieces.
Fields
aggregate: Arc<AggregateFunctionExpr>Physical aggregate expression that can be used by an aggregate execution plan.
filter: Option<Arc<dyn PhysicalExpr>>Optional physical filter expression for FILTER (WHERE ...).
order_bys: Vec<PhysicalSortExpr>Physical ordering expressions from aggregate ORDER BY.