Module execution_props

Module execution_props 

Structs

ExecutionProps
Holds properties and scratch state used while optimizing a LogicalPlan and translating it into an executable physical plan, such as the statement start time used during simplification.

Enums

VarType
Variable type, system/user defined

Traits

VarProvider
A var provider for @variable and @@variable runtime values.