pub struct CaseExpr { /* private fields */ }Expand description
The CASE expression is similar to a series of nested if/else and there are two forms that can be used. The first form consists of a series of boolean “when” expressions with corresponding “then” expressions, and an optional “else” expression.
CASE WHEN condition THEN result [WHEN …] [ELSE result] END
The second form uses a base expression and then a series of “when” clauses that match on a literal value.
CASE expression WHEN value THEN result [WHEN …] [ELSE result] END
Implementations
Sourceimpl CaseExpr
impl CaseExpr
Sourcepub fn try_new(
expr: Option<Arc<dyn PhysicalExpr>>,
when_then_expr: Vec<(Arc<dyn PhysicalExpr>, Arc<dyn PhysicalExpr>)>,
else_expr: Option<Arc<dyn PhysicalExpr>>,
) -> Result<Self>
pub fn try_new( expr: Option<Arc<dyn PhysicalExpr>>, when_then_expr: Vec<(Arc<dyn PhysicalExpr>, Arc<dyn PhysicalExpr>)>, else_expr: Option<Arc<dyn PhysicalExpr>>, ) -> Result<Self>
Create a new CASE WHEN expression
Sourcepub fn expr(&self) -> Option<&Arc<dyn PhysicalExpr>>
pub fn expr(&self) -> Option<&Arc<dyn PhysicalExpr>>
Optional base expression that can be compared to literal values in the “when” expressions
Sourcepub fn when_then_expr(
&self,
) -> &[(Arc<dyn PhysicalExpr>, Arc<dyn PhysicalExpr>)]
pub fn when_then_expr( &self, ) -> &[(Arc<dyn PhysicalExpr>, Arc<dyn PhysicalExpr>)]
One or more when/then expressions
Sourcepub fn else_expr(&self) -> Option<&Arc<dyn PhysicalExpr>>
pub fn else_expr(&self) -> Option<&Arc<dyn PhysicalExpr>>
Optional “else” expression