Module projection

Module projection 

ProjectionExpr and ProjectionExprs for representing projections.

Structs

ProjectionExpr
An expression used by projection operations.
ProjectionExprs
A collection of ProjectionExpr instances, representing a complete projection operation.
ProjectionMapping
Stores the mapping between source expressions and target expressions for a projection.
ProjectionTargets
Stores target expressions, along with their indices, that associate with a source expression in a projection mapping.
Projector
Applies a projection to record batches.

Functions

combine_projections
Combine two projections.
project_ordering
Projects a single LexOrdering onto the given schema.
project_orderings
Projects a slice of LexOrderings onto the given schema.
update_expr
The function projects / unprojects an expression with respect to set of projection expressions.

Type Aliases

ProjectionRef
Describes an immutable reference counted projection.