ProjectionRef

Type Alias ProjectionRef 

pub type ProjectionRef = Arc<[usize]>;
Describes an immutable reference counted projection.

This structure represents projecting a set of columns by index. Arc is used to make it cheap to clone.

Aliased Type

pub struct ProjectionRef { /* private fields */ }