pub struct ExprOrdering {
pub expr: Arc<dyn PhysicalExpr>,
pub state: SortProperties,
pub children_states: Vec<SortProperties>,
}Expand description
The ExprOrdering struct is designed to aid in the determination of ordering (represented
by SortProperties) for a given PhysicalExpr. When analyzing the orderings
of a PhysicalExpr, the process begins by assigning the ordering of its leaf nodes.
By propagating these leaf node orderings upwards in the expression tree, the overall
ordering of the entire PhysicalExpr can be derived.
This struct holds the necessary state information for each expression in the PhysicalExpr.
It encapsulates the orderings (state) associated with the expression (expr), and
orderings of the children expressions (children_states). The ExprOrdering of a parent
expression is determined based on the ExprOrdering states of its children expressions.
Fields
expr: Arc<dyn PhysicalExpr>state: SortPropertieschildren_states: Vec<SortProperties>Implementations
sourceimpl ExprOrdering
impl ExprOrdering
sourcepub fn new(expr: Arc<dyn PhysicalExpr>) -> Self
pub fn new(expr: Arc<dyn PhysicalExpr>) -> Self
Creates a new ExprOrdering with SortProperties::Unordered states
for expr and its children.
sourcepub fn with_new_children(self, children_states: Vec<SortProperties>) -> Self
pub fn with_new_children(self, children_states: Vec<SortProperties>) -> Self
Updates this ExprOrdering’s children states with the given states.
sourcepub fn children_expr_orderings(&self) -> Vec<ExprOrdering>
pub fn children_expr_orderings(&self) -> Vec<ExprOrdering>
Creates new ExprOrdering objects for each child of the expression.