Module stats_solver

Module stats_solver 

DAG-based statistics propagation for the Statistics V2 framework.

All public items in this module are deprecated as of 54.0.0. See https://github.com/apache/datafusion/pull/22071 for details.

Structs

ExprStatisticsGraphDeprecated
This object implements a directed acyclic expression graph (DAEG) that is used to compute statistics/distributions for expressions hierarchically.
ExprStatisticsGraphNodeDeprecated
This is a node in the DAEG; it encapsulates a reference to the actual PhysicalExpr as well as its statistics/distribution.