Structs
- Execution
Props - Holds properties and scratch state used while optimizing a
LogicalPlanand translating it into an executable physical plan, such as the statement start time used during simplification.
Enums
- VarType
- Variable type, system/user defined
Traits
- VarProvider
- A var provider for
@variableand@@variableruntime values.