pub fn has_column_references(expr: &Arc<dyn PhysicalExpr>) -> bool👎Deprecated since 53.0.0:
This function isn’t used internally and is trivial to implement, therefore it will be removed in a future release.
Check if this expression has any column references.