pub fn simplify_not_expr(
expr: Arc<dyn PhysicalExpr>,
schema: &Schema,
) -> Result<Transformed<Arc<dyn PhysicalExpr>>>👎Deprecated since 53.0.0:
This function will be made private in a future release, please file an issue if you have a reason for keeping it public.
Attempts to simplify NOT expressions by applying one level of transformation
This function applies a single simplification rule and returns. When used with TreeNodeRewriter, multiple passes will automatically be applied until no more transformations are possible.