DAG-based statistics propagation for the Statistics V2 framework.
All public items in this module are deprecated as of 54.0.0.
See https://github.com/apache/datafusion/pull/22071 for details.
Structs
- Expr
Statistics Graph Deprecated - This object implements a directed acyclic expression graph (DAEG) that is used to compute statistics/distributions for expressions hierarchically.
- Expr
Statistics Graph Node Deprecated - This is a node in the DAEG; it encapsulates a reference to the actual
PhysicalExpras well as its statistics/distribution.