pub struct ExprStatisticsGraph { /* private fields */ }๐Deprecated since 54.0.0:
Part of the unused Statistics V2 framework; see https://github.com/apache/datafusion/pull/22071
This object implements a directed acyclic expression graph (DAEG) that is used to compute statistics/distributions for expressions hierarchically.
Implementations
Sourceimpl ExprStatisticsGraph
impl ExprStatisticsGraph
pub fn try_new(expr: Arc<dyn PhysicalExpr>, schema: &Schema) -> Result<Self>
Sourcepub fn assign_statistics(&mut self, assignments: &[(usize, Distribution)])
pub fn assign_statistics(&mut self, assignments: &[(usize, Distribution)])
This function assigns given distributions to expressions in the DAEG.
The argument assignments associates indices of sought expressions
with their corresponding new distributions.
Sourcepub fn evaluate_statistics(&mut self) -> Result<&Distribution>
pub fn evaluate_statistics(&mut self) -> Result<&Distribution>
Computes statistics/distributions for an expression via a bottom-up traversal.
Sourcepub fn propagate_statistics(
&mut self,
given_stats: Distribution,
) -> Result<PropagationResult>
pub fn propagate_statistics( &mut self, given_stats: Distribution, ) -> Result<PropagationResult>
Runs a propagation mechanism in a top-down manner to update statistics of leaf nodes.